@@ -3,14 +3,14 @@ from typing import Tuple
 
 import eyed3
 from eyed3.id3 import ID3_V2_4, ID3_V1_1
+from nuclear.sublog import wrap_context, log
 
 from trimmer.metadata import extract_artist_title
-from trimmer.sublog.sublog import wrap_context, info, warn
 
 
 def tag_mp3(mp3_file: str, artist: str, title: str):
     with wrap_context('tagging mp3', artist=artist, title=title, mp3_file=mp3_file):
-        info('tagging mp3...', artist=artist, title=title)
+        log.info('tagging mp3...', artist=artist, title=title)
 
         audiofile = eyed3.load(mp3_file)
         audiofile.tag.artist = artist
@@ -26,7 +26,7 @@ def read_mp3_artist_title(mp3_file: str) -> Tuple[str, str]:
         file_artist, file_title = extract_filename_artist_title(mp3_file)
         artist = tag_artist or file_artist
         title = tag_title or file_title
-        info('metadata inferred', artist=artist, title=title)
+        log.info('metadata inferred', artist=artist, title=title)
         return artist, title
 
 
@@ -35,12 +35,12 @@ def read_mp3_tags(mp3_file: str) -> Tuple[str, str]:
 
         audiofile = eyed3.load(mp3_file)
         if audiofile is None or audiofile.tag is None:
-            warn('no IDv3 tags read', mp3_file=mp3_file)
+            log.warn('no IDv3 tags read', mp3_file=mp3_file)
             return '', ''
 
         artist = audiofile.tag.artist.strip()
         title = audiofile.tag.title.strip()
-        info('IDv3 tags read', mp3_file=mp3_file, artist=artist, title=title)
+        log.info('IDv3 tags read', mp3_file=mp3_file, artist=artist, title=title)
         return artist, title
 
 
