@@ -2,10 +2,11 @@ import os
 import re
 from typing import Optional
 
+from nuclear.sublog import log, log_error, wrap_context
+
 from trimmer.downloader import download_from_youtube, extract_youtube_artist_title
 from trimmer.normalizer import normalize_song
 from trimmer.renamer import rename_song
-from trimmer.sublog.sublog import info, log_error, wrap_context
 from trimmer.tagger import read_mp3_artist_title
 from trimmer.tagger import tag_mp3
 
@@ -15,10 +16,10 @@ def trim_from_source(source: str, artist: Optional[str], title: Optional[str],
                      trim_start: Optional[float], trim_end: Optional[float], gain: Optional[float]):
     with log_error():
         if source_is_url(source):
-            info('source recognized as url', source=source)
+            log.info('source recognized as url', source=source)
             trim_url(source, artist, title, no_trim, no_fade, no_normalize, trim_start, trim_end, gain)
         elif source_is_mp3(source):
-            info('source recognized as mp3 file', source=source)
+            log.info('source recognized as mp3 file', source=source)
             trim_mp3(source, artist, title, no_trim, no_fade, no_normalize, trim_start, trim_end, gain)
         else:
             raise RuntimeError(f'unrecognized source: {source}')
@@ -29,7 +30,7 @@ def trim_url(url: str, user_artist: Optional[str], user_title: Optional[str],
              trim_start: Optional[float] = None, trim_end: Optional[float] = None, gain: Optional[float] = None):
     with wrap_context('url song'):
         yt_artist, yt_title = extract_youtube_artist_title(url)
-        info('artist & title extracted from youtube page', artist=yt_artist, title=yt_title)
+        log.info('artist & title extracted from youtube page', artist=yt_artist, title=yt_title)
         artist = user_artist or enter_or_default('Artist', default=yt_artist)
         title = user_title or enter_or_default('Title', default=yt_title)
 
@@ -38,7 +39,7 @@ def trim_url(url: str, user_artist: Optional[str], user_title: Optional[str],
         normalize_song(mp3_file, no_trim, no_fade, no_normalize, trim_start, trim_end, gain)
         tag_mp3(mp3_file, artist, title)
 
-        info('song saved', mp3_file=mp3_file)
+        log.info('song saved', mp3_file=mp3_file)
 
 
 def trim_mp3(file: str, user_artist: Optional[str], user_title: Optional[str],
@@ -55,7 +56,7 @@ def trim_mp3(file: str, user_artist: Optional[str], user_title: Optional[str],
         normalize_song(mp3_file, no_trim, no_fade, no_normalize, trim_start, trim_end, gain)
         tag_mp3(mp3_file, artist, title)
 
-        info('song saved', mp3_file=mp3_file)
+        log.info('song saved', mp3_file=mp3_file)
 
 
 def source_is_url(source: str) -> bool:
